Module mobile

Module mobile 

Mobile phone number validation with locale support

This module provides comprehensive mobile phone validation for different countries and locales. It supports over 150 country/locale combinations.

Structs

MobileOptions
Options for mobile phone validation

Enums

Locale
Locale type for validation

Functions

get_supported_locales
Returns a list of all supported locales
is_mobile_phone
Validates a mobile phone number with locale and options
is_valid_phone
Validates a mobile phone number (convenience function using ‘any’ locale)