Module numeric

Module numeric 

Numeric validation functions

Functions

is_close_to
Validates if a floating point number is within a tolerance of a target
is_even
Validates if a number is even
is_in_range
Validates if a number is within a specified range (inclusive)
is_multiple_of
Validates if a number is a multiple of another number
is_negative
Validates if a number is negative
is_odd
Validates if a number is odd
is_positive
Validates if a number is positive
is_zero
Validates if a number is zero