Numeric validation functions
Functions
- is_
close_ to - Validates if a floating point number is within a tolerance of a target
- is_even
- Validates if a number is even
- is_
in_ range - Validates if a number is within a specified range (inclusive)
- is_
multiple_ of - Validates if a number is a multiple of another number
- is_
negative - Validates if a number is negative
- is_odd
- Validates if a number is odd
- is_
positive - Validates if a number is positive
- is_zero
- Validates if a number is zero